OC.L10N.register(
    "logreader",
    {
    "Error parsing log" : "Fejl i fortolkning af log",
    "Copy" : "Kopier",
    "Copy raw" : "Kopier uformateret",
    "Copy formatted" : "Kopier formateret",
    "No server logs" : "Ingen server logs",
    "One or more entries are hidden by the log level filter" : "En eller flere indgange a skjult af log niveau filtret",
    "Everything is working fine" : "Alt virker efter hensigten",
    "Log levels" : "Log niveauer",
    "Log content" : "Log indhold",
    "Live update" : "Live opdateringer",
    "Download logs" : "Hent logs",
    "Logging" : "Logging",
    "Log Reader" : "Log aflæser",
    "A log reader for Nextcloud" : "En loglæser til Nextcloud",
    "Log reader for Nextcloud" : "Loglæser til Nextcloud",
    "Cased by " : "Arkiveret af"
},
"nplurals=2; plural=(n != 1);");
